@@ -203,12 +203,13 @@ colClass.ff <- function(x){
 #! \examples{
 #!     x <- data.frame(log=rep(c(FALSE, TRUE), length.out=26), int=1:26, dbl=1:26 + 0.1
 #! , fac=factor(letters), ord=ordered(LETTERS)
-#! , dct=Sys.time()+1:26, dat=seq(as.Date("1910/1/1"), length.out=26, by=1))
+#! , dct=Sys.time()+1:26, dat=seq(as.Date("1910/1/1"), length.out=26, by=1)
+#! , stringsAsFactors = TRUE)
 #!     x <- x[c(13:1, 13:1),]
 #!     csvfile <- tempPathFile(path=getOption("fftempdir"), extension="csv")
 #!     write.csv(x, file=csvfile, row.names=FALSE)
 #!
-#!     y <- read.csv(file=csvfile, header=TRUE)
+#!     y <- read.csv(file=csvfile, header=TRUE, stringsAsFactors = TRUE)
 #!     y
 #!     cat("Read csv with header\n")
 #!     ffx <- read.csv.ffdf(file=csvfile, header=TRUE)
@@ -216,12 +217,15 @@ colClass.ff <- function(x){
 #!     sapply(ffx[,], class)
 #!
 #!     message("NOTE that read.table fails for ordered factors, this is fixed in read.table.ffdf")
-#!     try(read.csv(file=csvfile, header=TRUE, colClasses=c(ord="ordered")))
+#!     try(read.csv(file=csvfile, header=TRUE, colClasses=c(ord="ordered"), stringsAsFactors = TRUE))
 #!     # TODO could fix this with the following two commands (Gabor Grothendieck) 
 #!     # but does not know what bad side-effects this could have
 #!      #setOldClass("ordered")
 #!      #setAs("character", "ordered", function(from) ordered(from))
-#!     y <- read.csv(file=csvfile, header=TRUE, colClasses=c(dct="POSIXct", dat="Date"))
+#!     y <- read.csv(file=csvfile, header=TRUE
+#!     , colClasses=c(dct="POSIXct", dat="Date")
+#!     , stringsAsFactors = TRUE
+#!     )
 #!     y
 #!
 #!     ffx <- read.csv.ffdf(file=csvfile, header=TRUE
@@ -236,7 +240,7 @@ colClass.ff <- function(x){
 #! , VERBOSE=TRUE)
 #!     y <- ffx$fac[]
 #!     print(levels(y))
-#!     data.frame(values=as.character(y), codes=as.integer(y))
+#!     data.frame(values=as.character(y), codes=as.integer(y), stringsAsFactors = TRUE)
 #!
 #!     message("If we don't know the levels we can sort then after reading")
 #!     message("(Will rewrite all factor codes)")
@@ -244,7 +248,7 @@ colClass.ff <- function(x){
 #!     ffx <- sortLevels(ffx)
 #!     y <- ffx$fac[]
 #!     print(levels(y))
-#!     data.frame(values=as.character(y), codes=as.integer(y))
+#!     data.frame(values=as.character(y), codes=as.integer(y), stringsAsFactors = TRUE)
 #!
 #!     message("If we KNOW the levels we can fix levels upfront")
 #!     ffx <- read.csv.ffdf(file=csvfile, header=TRUE
@@ -252,7 +256,7 @@ colClass.ff <- function(x){
 #! , first.rows=6, next.rows=10, levels=list(fac=letters, ord=LETTERS))
 #!     y <- ffx$fac[]
 #!     print(levels(y))
-#!     data.frame(values=as.character(y), codes=as.integer(y))
+#!     data.frame(values=as.character(y), codes=as.integer(y), stringsAsFactors = TRUE)
 #!
 #!     message("Or we inspect a sufficiently large chunk of data and use those")
 #!     ffx1 <- read.csv.ffdf(file=csvfile, header=TRUE
@@ -292,28 +296,30 @@ colClass.ff <- function(x){
 #!     fwffile <- tempfile()
 #!
 #!     cat(file=fwffile, "123456", "987654", sep="\n")
-#!     x <- read.fwf(fwffile, widths=c(1,2,3))    #> 1 23 456 \ 9 87 654
+#!     x <- read.fwf(fwffile, widths=c(1,2,3), stringsAsFactors = TRUE)    #> 1 23 456 \ 9 87 654
 #!     y <- read.table.ffdf(file=fwffile, FUN="read.fwf", widths=c(1,2,3))
 #!     stopifnot(identical(x, y[,]))
-#!     x <- read.fwf(fwffile, widths=c(1,-2,3))   #> 1 456 \ 9 654
+#!     x <- read.fwf(fwffile, widths=c(1,-2,3), stringsAsFactors = TRUE)   #> 1 456 \ 9 654
 #!     y <- read.table.ffdf(file=fwffile, FUN="read.fwf", widths=c(1,-2,3))
 #!     stopifnot(identical(x, y[,]))
 #!     unlink(fwffile)
 #!
 #!     cat(file=fwffile, "123", "987654", sep="\n")
-#!     x <- read.fwf(fwffile, widths=c(1,0, 2,3))    #> 1 NA 23 NA \ 9 NA 87 654
+#!     x <- read.fwf(fwffile, widths=c(1,0, 2,3)
+#!     , stringsAsFactors = TRUE)    #> 1 NA 23 NA \ 9 NA 87 654
 #!     y <- read.table.ffdf(file=fwffile, FUN="read.fwf", widths=c(1,0, 2,3))
 #!     stopifnot(identical(x, y[,]))
 #!     unlink(fwffile)
 #!
 #!     cat(file=fwffile, "123456", "987654", sep="\n")
-#!     x <- read.fwf(fwffile, widths=list(c(1,0, 2,3), c(2,2,2))) #> 1 NA 23 456 98 76 54
+#!     x <- read.fwf(fwffile, widths=list(c(1,0, 2,3), c(2,2,2))
+#!     , stringsAsFactors = TRUE) #> 1 NA 23 456 98 76 54
 #!     y <- read.table.ffdf(file=fwffile, FUN="read.fwf", widths=list(c(1,0, 2,3), c(2,2,2)))
 #!     stopifnot(identical(x, y[,]))
 #!     unlink(fwffile)
 #!
 #!     \dontshow{
-#!        x <- read.csv(file=csvfile, header=TRUE)
+#!        x <- read.csv(file=csvfile, header=TRUE, stringsAsFactors = TRUE)
 #!
 #!        y <- read.csv.ffdf(file=csvfile, header=TRUE)
 #!        stopifnot(identical(x, y[,]))
@@ -391,9 +397,12 @@ read.table.ffdf <- function(
 
   if (!is.null(rt.args$as.is))
     stop("argument 'as.is' not allowed, all columns must be read as factors or ordered factors")
-  if (!is.null(rt.args$stringsAsFactors))
-    stop("argument 'stringsAsFactors' not allowed, all columns must be read as factors or ordered factors")
-
+  if (is.null(rt.args$stringsAsFactors)){
+    rt.args$stringsAsFactors <- TRUE
+  }else if (!rt.args$stringsAsFactors){
+    warning("setting 'stringsAsFactors == TRUE', all columns must be read as factors or ordered factors")
+    rt.args$stringsAsFactors <- TRUE
+  }
 
   # { begin 1:1 from read.table
   if (is.character(file)) {
@@ -698,7 +707,7 @@ read.table.ffdf <- function(
 #! \examples{
 #!    x <- data.frame(log=rep(c(FALSE, TRUE), length.out=26), int=1:26, dbl=1:26 + 0.1
 #! , fac=factor(letters), ord=ordered(LETTERS), dct=Sys.time()+1:26
-#! , dat=seq(as.Date("1910/1/1"), length.out=26, by=1))
+#! , dat=seq(as.Date("1910/1/1"), length.out=26, by=1), stringsAsFactors = TRUE)
 #!    ffx <- as.ffdf(x)
 #!
 #!    csvfile <- tempPathFile(path=getOption("fftempdir"), extension="csv")
@@ -721,7 +730,7 @@ read.table.ffdf <- function(
 #!   system.time({
 #!     x <- data.frame(log=rep(c(FALSE, TRUE), length.out=26), int=1:26, dbl=1:26 + 0.1
 #! , fac=factor(letters), ord=ordered(LETTERS), dct=Sys.time()+1:26
-#! , dat=seq(as.Date("1910/1/1"), length.out=26, by=1))
+#! , dat=seq(as.Date("1910/1/1"), length.out=26, by=1), stringsAsFactors = TRUE)
 #!     x <- do.call("rbind", rep(list(x), 10))
 #!     x <- do.call("rbind", rep(list(x), 10))
 #!     x <- do.call("rbind", rep(list(x), 10))
